﻿using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.IO;
using System.Text;
using System.Data;
using System.Drawing;
using System.Data.SqlClient;
using System.Configuration;
using iTextSharp.text;
using iTextSharp.text.pdf;
using iTextSharp.tool.xml;

public partial class CS : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!this.IsPostBack)
        {
            this.BindGrid();
        }
    }

    private void BindGrid()
    {
        string constr = ConfigurationManager.ConnectionStrings["constr"].ConnectionString;
        using (SqlConnection con = new SqlConnection(constr))
        {
            using (SqlCommand cmd = new SqlCommand("SELECT * FROM Customers"))
            {
                using (SqlDataAdapter sda = new SqlDataAdapter())
                {
                    cmd.Connection = con;
                    sda.SelectCommand = cmd;
                    using (DataTable dt = new DataTable())
                    {
                        sda.Fill(dt);
                        gvCustomers.DataSource = dt;
                        gvCustomers.DataBind();
                    }
                }
            }
        }
    }

    protected void OnPageIndexChanging(object sender, GridViewPageEventArgs e)
    {
        gvCustomers.PageIndex = e.NewPageIndex;
        this.BindGrid();
    }

    protected void ExportToWord(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.doc");
        Response.Charset = "";
        Response.ContentType = "application/vnd.ms-word";
        using (StringWriter sw = new StringWriter())
        {
            HtmlTextWriter hw = new HtmlTextWriter(sw);

            //To Export all pages.
            gvCustomers.AllowPaging = false;
            this.BindGrid();

            gvCustomers.HeaderRow.BackColor = Color.White;
            foreach (TableCell cell in gvCustomers.HeaderRow.Cells)
            {
                cell.BackColor = gvCustomers.HeaderStyle.BackColor;
            }
            foreach (GridViewRow row in gvCustomers.Rows)
            {
                row.BackColor = Color.White;
                foreach (TableCell cell in row.Cells)
                {
                    if (row.RowIndex % 2 == 0)
                    {
                        cell.BackColor = gvCustomers.AlternatingRowStyle.BackColor;
                    }
                    else
                    {
                        cell.BackColor = gvCustomers.RowStyle.BackColor;
                    }
                }
            }

            gvCustomers.RenderControl(hw);

            Response.Output.Write(sw.ToString());
            Response.Flush();
            Response.End();
        }
    }

    protected void ExportToExcel(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.xls");
        Response.Charset = "";
        Response.ContentType = "application/vnd.ms-excel";
        using (StringWriter sw = new StringWriter())
        {
            HtmlTextWriter hw = new HtmlTextWriter(sw);

            //To Export all pages.
            gvCustomers.AllowPaging = false;
            this.BindGrid();

            gvCustomers.HeaderRow.BackColor = Color.White;
            foreach (TableCell cell in gvCustomers.HeaderRow.Cells)
            {
                cell.BackColor = gvCustomers.HeaderStyle.BackColor;
            }
            foreach (GridViewRow row in gvCustomers.Rows)
            {
                row.BackColor = Color.White;
                foreach (TableCell cell in row.Cells)
                {
                    if (row.RowIndex % 2 == 0)
                    {
                        cell.BackColor = gvCustomers.AlternatingRowStyle.BackColor;
                    }
                    else
                    {
                        cell.BackColor = gvCustomers.RowStyle.BackColor;
                    }
                    cell.CssClass = "textmode";
                }
            }
            gvCustomers.RenderControl(hw);

            //Style to format numbers to string.
            string style = @"<style> .textmode { mso-number-format:\@; } </style>";
            Response.Write(style);
            Response.Output.Write(sw.ToString());
            Response.Flush();
            Response.End();
        }
    }

    protected void ExportToPDF(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.pdf");
        Response.Charset = "";
        Response.ContentType = "application/pdf";

        //To Export all pages.
        gvCustomers.AllowPaging = false;
        this.BindGrid();

        using (StringWriter sw = new StringWriter())
        {
            using (HtmlTextWriter hw = new HtmlTextWriter(sw))
            {
                gvCustomers.RenderControl(hw);
                using (StringReader sr = new StringReader(sw.ToString()))
                {
                    using (Document pdfDoc = new Document(PageSize.A4, 10f, 10f, 10f, 0f))
                    {
                        using (PdfWriter writer = PdfWriter.GetInstance(pdfDoc, Response.OutputStream))
                        {
                            pdfDoc.Open();
                            XMLWorkerHelper.GetInstance().ParseXHtml(writer, pdfDoc, sr);
                            pdfDoc.Close();
                            Response.Cache.SetCacheability(HttpCacheability.NoCache);
                            Response.Write(pdfDoc);
                            Response.End();
                        }
                    }
                }
            }
        }
    }

    protected void ExportToCSV(object sender, EventArgs e)
    {
        Response.Clear();
        Response.Buffer = true;
        Response.AddHeader("content-disposition", "attachment;filename=GridViewExport.csv");
        Response.Charset = "";
        Response.ContentType = "text/csv";

        //To Export all pages.
        gvCustomers.AllowPaging = false;
        this.BindGrid();

        StringBuilder sb = new StringBuilder();
        foreach (TableCell cell in gvCustomers.HeaderRow.Cells)
        {
            //Append data with separator.
            sb.Append(cell.Text + ',');
        }
        //Append new line character.
        sb.Append("\r\n");

        foreach (GridViewRow row in gvCustomers.Rows)
        {
            foreach (TableCell cell in row.Cells)
            {
                //Append data with separator.
                sb.Append(cell.Text + ',');
            }
            //Append new line character.
            sb.Append("\r\n");
        }

        Response.Output.Write(sb.ToString());
        Response.Flush();
        Response.End();
    }

    public override void VerifyRenderingInServerForm(Control control)
    {
        /* Verifies that the control is rendered */
    }
}